@@ -1,3 +1,7 @@
+##' @importFrom magrittr %>%
+##' @export
+magrittr::`%>%`
+
 ##' @importFrom ggplot2 ggplot_add
 ##' @export
 ggplot2::ggplot_add
